SHA2_256_x86

Struct SHA2_256_x86 

pub struct SHA2_256_x86 { /* private fields */ }
An x86 and x86_64 optimized implementation of the SHA2_256 algorithm.

This implementation is only available on x86 and x86_64 targets. The code will panic if the target is invalid.

Safety

This implementation does not verify that the target supports the required instructions. In particular sha,sse4.1 features have to be supported. Otherwise the code will likely crash at runtime.

Implementations

Source

impl SHA2_256_x86

pub const fn new() -> Self

Creates a new SHA2_256_x86 instance.

Panics

If target_arch is neither x86 nor x86_64.

pub fn update(&mut self, data: impl AsRef<[u8]>)

Writes a block of data to the underlying state.

pub fn result(&self, output: &mut [u8; 32])

Calculates the final hash value.