pub struct SHA2_256_aarch64 { /* private fields */ }Expand description
An aarch64 optimized implementation of the SHA2_256 algorithm.
This implementation is only available on aarch64 targets.
The code will panic if the target is invalid.
Safety
This implementation does not verify that the target supports the required instructions.
In particular sha2 feature has to be supported. Otherwise the code will
likely crash at runtime.
Implementations