pub struct SHA2_256_x86 { /* private fields */ }Expand description
An x86 and x86_64 optimized implementation of the SHA2_256 algorithm.
This implementation is only available on x86 and x86_64 targets.
The code will panic if the target is invalid.
Safety
This implementation does not verify that the target supports the required instructions.
In particular sha,sse4.1 features have to be supported. Otherwise the code will
likely crash at runtime.
Implementations